smartcard.Synchronization

# ``smartcard`.`Synchronization``

module documentation

from Thinking in Python, Bruce Eckel http://python-3-patterns-idioms-test.readthedocs.org/en/latest/Observer.html

(c) Copyright 2008, Creative Commons Attribution-Share Alike 3.0.

Simple emulation of Java's 'synchronized' keyword, from Peter Norvig.

Class | `Synchronization` | Undocumented
Function | `synchronize` | Synchronize methods in the given class. Only synchronize the methods whose names are given, or all methods if names=None.
Function | `synchronized` | Undocumented

def synchronize(klass, names=None):

Synchronize methods in the given class. Only synchronize the methods whose names are given, or all methods if names=None.

def synchronized(method):

Undocumented